@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2019  David Redondo <kde@david-redondo.de>
+ * SPDX-FileCopyrightText: 2019 David Redondo <kde@david-redondo.de>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  */
 
 #include <QAction>
@@ -29,8 +17,7 @@
 int main(int argc, char **argv)
 {
     QCoreApplication app(argc, argv);
-    QDBusInterface khotkeys(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/khotkeys"),
-        QStringLiteral("org.kde.khotkeys"));
+    QDBusInterface khotkeys(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/khotkeys"), QStringLiteral("org.kde.khotkeys"));
     khotkeys.call(QStringLiteral("declareConfigOutDated"));
     KConfig khotkeysrc(QStringLiteral("khotkeysrc"), KConfig::SimpleConfig);
     const int dataCount = KConfigGroup(&khotkeysrc, "Data").readEntry("DataCount", 0);
@@ -57,7 +44,7 @@ int main(int argc, char **argv)
         }
         const QString storageId = KConfigGroup(&khotkeysrc, groupName + QStringLiteral("Actions0")).readEntry("CommandURL");
         const QString id = KConfigGroup(&khotkeysrc, groupName + QStringLiteral("Triggers0")).readEntry("Uuid");
-        //ask globalaccel about the current shortcut rather than parsing it ourselves
+        // ask globalaccel about the current shortcut rather than parsing it ourselves
         const QList<QKeySequence> shortcut = KGlobalAccel::self()->globalShortcut(QStringLiteral("khotkeys"), id);
         QAction action;
         action.setObjectName(id);
